@@ -17,6 +17,7 @@ import time
 import urllib
 
 import aiohttp
+import chardet
 
 _loggerName = 'beniutils'
 
@@ -262,6 +263,12 @@ def getClassFullName(classItem):
     return getattr(classItem, '__module__') + '.' + getattr(classItem, '__name__')
 
 
+def decode(value):
+    data = chardet.detect(value)
+    encoding = data["encoding"]
+    return value.decode(encoding)
+
+
 def getTempWorkspace(clearOneDayBefore=True):
     baseWorkspaceFoler = getPath(os.path.expanduser("~"), "beniutils.workspace")
     makeFolder(baseWorkspaceFoler)
@@ -280,7 +287,7 @@ def getTempWorkspace(clearOneDayBefore=True):
     raise Exception("创建tempWorkspace目录失败")
 
 
-def execute(*pars, showCmd=True, ignoreError=False):
+def execute(*pars, showCmd=True, showOutput=False, ignoreError=False):
     cmd = ' '.join(pars)
     if showCmd:
         info(cmd)
@@ -292,9 +299,14 @@ def execute(*pars, showCmd=True, ignoreError=False):
     )
     outBytes, errBytes = p.communicate()
     p.kill()
-    if not ignoreError and errBytes:
-        error(f"output: {outBytes}")
-        error(f"error: {errBytes}")
+    if showOutput:
+        outStr = decode(outBytes).replace("\r\n", "\n")
+        errStr = decode(errBytes).replace("\r\n", "\n")
+        if outStr:
+            info(f"output:\n{outStr}")
+        if errStr:
+            info(f"error:\n{errStr}")
+    if not ignoreError and p.returncode != 0:
         raise Exception("执行命令出错")
     return p.returncode, outBytes, errBytes
 
