@@ -101,8 +101,3 @@ def initParDict():
 def isDev():
     return sys.executable.endswith("python.exe")
 
-
-def create(targetPath):
-    currentFolder = os.path.dirname(__file__)
-    taskZipfile = b.getPath(currentFolder, "data/task.zip")
-    b.zipFileExtract(taskZipfile, targetPath)
